@@ -236,7 +236,7 @@ def video_writer(filename: str, vcodec: str = 'libx264', framerate: float = 25,
 
 def write_video(filename: str, frames: Union[np.ndarray, list], offset: float = 0.0, scale: float = 1.0, gamma: float = 1.0,
                 masks: Union[np.ndarray, list, bool] = None, background: Union[np.ndarray, list, tuple] = None,
-                cycle: bool = False,
+                loop: bool = False,
                 ffmpeg_path=None, verbosity: int = 0, **kwargs):
     """given a sequence of frames (as 4D np.ndarray or as list of 3D np.ndarrays), export a video using FFMPEG;
 
@@ -255,8 +255,8 @@ def write_video(filename: str, frames: Union[np.ndarray, list], offset: float =
     alternatively, the video sequence can be alpha blended against a background, either a constant value, color, or a
     static background image
 
-    cycle sequence
-    set cycle = True for poor man's looped animations where the reversed animation is prepended (doubling the number of
+    loop sequence
+    set loop = True for poor man's looped animations where the reversed animation is appended (doubling the number of
     frames as a side effect)
 
     additional arguments:
@@ -298,7 +298,7 @@ def write_video(filename: str, frames: Union[np.ndarray, list], offset: float =
         raise NotImplementedError('unexpected file extension: ' + ext)
 
     frame_inds = np.r_[:len(frames)]
-    if cycle:
+    if loop:
         frame_inds = np.r_[frame_inds, frame_inds[::-1]]
 
     for fi in frame_inds:
